@@ -70,7 +70,7 @@ function(object, cnet, betas, sigmas) {
   object@maxCategories <- cnet@maxCategories
   object@probabilities <- cnet@probabilities
 
-  if(is.null(betas)) {
+  if(is.null(betas) || length(betas) != object@numnodes) {
     betas <- vector("list", object@numnodes)
     for(i in 1:object@numnodes) {
       ncats <- length(object@categories[[i]])
@@ -79,6 +79,11 @@ function(object, cnet, betas, sigmas) {
       betas[[i]] <- seq(0, 1, 1/(ncats-1))[1:ncats]
     }
   }
+  else {
+    for(i in 1:object@numnodes)
+      betas[[i]] <- as.numeric(betas[[i]])
+  }
+          
   if(is.null(sigmas)) {
     sigmas <- rep(1, object@numnodes)
     for(i in 1:object@numnodes) {
@@ -112,8 +117,8 @@ function(object, cnet, lambdas) {
   object@maxCategories <- cnet@maxCategories
   object@probabilities <- cnet@probabilities
 
-  if(is.null(lambdas)) {
-    betas <- vector("list", object@numnodes)
+  if(is.null(lambdas) || length(lambdas) != object@numnodes) {
+    lambdas <- vector("list", object@numnodes)
     for(i in 1:object@numnodes) {
       ncats <- length(object@categories[[i]])
       if(ncats < 2)
@@ -121,6 +126,10 @@ function(object, cnet, lambdas) {
       lambdas[[i]] <- seq(1, ncats)
     }
   }
+  else {
+    for(i in 1:object@numnodes)
+      lambdas[[i]] <- as.numeric(lambdas[[i]])
+  }
   
   object@betas <- lambdas
   object@sigmas <- rep(0, object@numnodes)
@@ -145,8 +154,8 @@ function(object, cnet, lambdas) {
   object@maxCategories <- cnet@maxCategories
   object@probabilities <- cnet@probabilities
 
-  if(is.null(lambdas)) {
-    betas <- vector("list", object@numnodes)
+  if(is.null(lambdas) || length(lambdas) != object@numnodes) {
+    lambdas <- vector("list", object@numnodes)
     for(i in 1:object@numnodes) {
       ncats <- length(object@categories[[i]])
       if(ncats < 2)
@@ -154,6 +163,10 @@ function(object, cnet, lambdas) {
       lambdas[[i]] <- seq(1, ncats)
     }
   }
+  else {
+    for(i in 1:object@numnodes)
+      lambdas[[i]] <- as.numeric(lambdas[[i]])
+  }
   
   object@betas <- lambdas
   object@sigmas <- rep(0, object@numnodes)
